build library
Builder entry point — see build.yaml.
The builder implementation lives in lib/src/builder.dart and is
registered automatically by build_runner via build.yaml.
You do not need to import this library directly.
Builder entry point — see build.yaml.
The builder implementation lives in lib/src/builder.dart and is
registered automatically by build_runner via build.yaml.
You do not need to import this library directly.