CustomError class

Constructors

CustomError({required Image errorImage, required String errorTitle, required String errorMessage, String? buttonTitle, VoidCallback? retryAction})
const

Properties

buttonTitle String?
final
errorImage Image
final
errorMessage String
final
errorTitle String
final
hashCode int
The hash code for this object.
no setteroverride
retryAction VoidCallback?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override