registerReferenceWidth static method
Registers a custom reference width to be used for scaling calculations.
Implementation
static void registerReferenceWidth(double width) {
_referenceWidth = width;
}
Registers a custom reference width to be used for scaling calculations.
static void registerReferenceWidth(double width) {
_referenceWidth = width;
}