DeviceSecurityHelper class

Stub implementation of DeviceSecurityHelper for web and unsupported platforms.

All checks return isSecure as true because jailbreak/root detection only applies to Android and iOS.

Constructors

DeviceSecurityHelper()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

checkDeviceSecurity({bool checkDebugging = true, bool checkEmulator = true, String? bundleId, String? expectedHash, List<String>? flutterSecrets, String? apkPath, String? ipaPath}) Future<SecurityCheckResult>