FontWeightProtocol class abstract

A protocol for font weight types used by FontHelper

This abstract class defines the contract for font weight implementations. Any class implementing this protocol must provide a numeric weight value that corresponds to standard font weight values (100-900).

Constructors

FontWeightProtocol()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
weightValue int
Returns the numeric weight value (100-900)
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited