supported property
List<SupportedLocale>
get
supported
Projects may override only if they want to customize the list.
Implementation
List<SupportedLocale> get supported => SupportedLocale.values;
Projects may override only if they want to customize the list.
List<SupportedLocale> get supported => SupportedLocale.values;