SupportedLocale enum
Enum for supported locales with their string representations.
Values
- ar → const SupportedLocale
-
const SupportedLocale("ar") - arAE → const SupportedLocale
-
const SupportedLocale("ar_AE") - arBH → const SupportedLocale
-
const SupportedLocale("ar_BH") - arDZ → const SupportedLocale
-
const SupportedLocale("ar_DZ") - arEG → const SupportedLocale
-
const SupportedLocale("ar_EG") - arIQ → const SupportedLocale
-
const SupportedLocale("ar_IQ") - arJO → const SupportedLocale
-
const SupportedLocale("ar_JO") - arKW → const SupportedLocale
-
const SupportedLocale("ar_KW") - arLB → const SupportedLocale
-
const SupportedLocale("ar_LB") - arLY → const SupportedLocale
-
const SupportedLocale("ar_LY") - arMA → const SupportedLocale
-
const SupportedLocale("ar_MA") - arOM → const SupportedLocale
-
const SupportedLocale("ar_OM") - arQA → const SupportedLocale
-
const SupportedLocale("ar_QA") - arSA → const SupportedLocale
-
const SupportedLocale("ar_SA") - arSD → const SupportedLocale
-
const SupportedLocale("ar_SD") - arSY → const SupportedLocale
-
const SupportedLocale("ar_SY") - arTN → const SupportedLocale
-
const SupportedLocale("ar_TN") - arYE → const SupportedLocale
-
const SupportedLocale("ar_YE") - en → const SupportedLocale
-
const SupportedLocale("en") - enAu → const SupportedLocale
-
const SupportedLocale("en_AU") - enCa → const SupportedLocale
-
const SupportedLocale("en_CA") - enGb → const SupportedLocale
-
const SupportedLocale("en_GB") - enUs → const SupportedLocale
-
const SupportedLocale("en_US") - de → const SupportedLocale
-
const SupportedLocale("de") - deDe → const SupportedLocale
-
const SupportedLocale("de_DE") - deAt → const SupportedLocale
-
const SupportedLocale("de_AT") - deCh → const SupportedLocale
-
const SupportedLocale("de_CH") - es → const SupportedLocale
-
const SupportedLocale("es") - esEs → const SupportedLocale
-
const SupportedLocale("es_ES") - esMx → const SupportedLocale
-
const SupportedLocale("es_MX") - fr → const SupportedLocale
-
const SupportedLocale("fr") - frCa → const SupportedLocale
-
const SupportedLocale("fr_CA") - frFr → const SupportedLocale
-
const SupportedLocale("fr_FR") - caEs → const SupportedLocale
-
const SupportedLocale("ca_ES") - csCz → const SupportedLocale
-
const SupportedLocale("cs_CZ") - daDk → const SupportedLocale
-
const SupportedLocale("da_DK") - elGr → const SupportedLocale
-
const SupportedLocale("el_GR") - fiFi → const SupportedLocale
-
const SupportedLocale("fi_FI") - hiIn → const SupportedLocale
-
const SupportedLocale("hi_IN") - hrHr → const SupportedLocale
-
const SupportedLocale("hr_HR") - huHu → const SupportedLocale
-
const SupportedLocale("hu_HU") - idId → const SupportedLocale
-
const SupportedLocale("id_ID") - itIt → const SupportedLocale
-
const SupportedLocale("it_IT") - jaJp → const SupportedLocale
-
const SupportedLocale("ja_JP") - koKr → const SupportedLocale
-
const SupportedLocale("ko_KR") - msMy → const SupportedLocale
-
const SupportedLocale("ms_MY") - nbNo → const SupportedLocale
-
const SupportedLocale("nb_NO") - nlNl → const SupportedLocale
-
const SupportedLocale("nl_NL") - plPl → const SupportedLocale
-
const SupportedLocale("pl_PL") - ptBr → const SupportedLocale
-
const SupportedLocale("pt_BR") - ptPt → const SupportedLocale
-
const SupportedLocale("pt_PT") - roRo → const SupportedLocale
-
const SupportedLocale("ro_RO") - ruRu → const SupportedLocale
-
const SupportedLocale("ru_RU") - skSk → const SupportedLocale
-
const SupportedLocale("sk_SK") - svSe → const SupportedLocale
-
const SupportedLocale("sv_SE") - thTh → const SupportedLocale
-
const SupportedLocale("th_TH") - trTr → const SupportedLocale
-
const SupportedLocale("tr_TR") - ukUa → const SupportedLocale
-
const SupportedLocale("uk_UA") - viVn → const SupportedLocale
-
const SupportedLocale("vi_VN") - zhCn → const SupportedLocale
-
const SupportedLocale("zh_CN") - zhHk → const SupportedLocale
-
const SupportedLocale("zh_HK") - zhTw → const SupportedLocale
-
const SupportedLocale("zh_TW")
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- locale → Locale
-
no setter
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - rawValue → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
SupportedLocale> - A constant List of the values in this enum, in order of their declaration.