key property
The unique string key used for storage. Ensure keys are unique across the entire app namespace.
Implementation
final String key;
The unique string key used for storage. Ensure keys are unique across the entire app namespace.
final String key;