core library
======================= DESIGN SYSTEM
Classes
- AppCupertinoButton
- BasePreferences
- --- PREFERENCE SYSTEM ARCHITECTURE ---
- CustomError
- CustomErrorState
- DeviceHelper
- Device-specific utilities for responsive design
- DeviceRegistry
- Centralized registry for managing device-specific settings in the design system.
- DeviceSecurityHelper
- Stub implementation of DeviceSecurityHelper for web and unsupported platforms.
- ErrorView
- FontHelper
- FontKey
- FontRegistry
- FontWeightProtocol
- A protocol for font weight types used by FontHelper
- ForceUpdateError
- GeneratePreferences
-
Annotates a class that extends
BasePreferencesto trigger code generation. - InApp
- Annotates a field for in-memory storage only.
- JailBroken
- LanguageManager
- Loaded
- Loading
- NoData
- NoNetwork
- OverlayLoading
-
PreferencesListener<
B extends StateStreamable< S> , S, T> - Internal widget that powers preferencesListener.
- SearchError
- Secure
-
Annotates a field to be stored securely via
FlutterSecureStorage. - SecurityCheckResult
- Security check result for platforms where native checks are unavailable.
- ServerError
- UnderlinedButton
- UnexpectedError
- UserDefault
-
Annotates a field for persistence in standard
SharedPreferences. - ViewState
Enums
- Position
- SupportedLocale
- Enum for supported locales with their string representations.
Functions
-
emptyBlocListener<
B extends StateStreamable< (S> , S>) → BlocListener< B, S> -
preferencesListener<
B extends StateStreamable< (S> , S, T>{required ValueListenable< T> listenTo, required void listener(BuildContext context, T value), bool listenWhen(T previous, T current)?}) → PreferencesListener<B, S, T> -
A function-based listener for preferences, designed to be used
within a
MultiBlocListener.