AppCupertinoButton class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
filled({required BuildContext context, required String title, required VoidCallback? onPressed, bool isDisabled = false, TextStyle? titleStyle, Color? backgroundColor, double height = 50, double horizontalPadding = 20, double? width, Color? shadowColor, double shadowBlurRadius = 0, IconData? icon, Color? iconColor, double iconSize = 22, Position iconPosition = Position.leading, Position labelPosition = Position.center})
→ Widget
-
-
outlined({required BuildContext context, required String title, required VoidCallback? onPressed, bool isDisabled = false, TextStyle? titleStyle, Color? borderColor, Color? backgroundColor, double backgroundOpacity = 0.0, double height = 50, double horizontalPadding = 20, double? width, double borderRadius = 12, double borderWidth = 1.5, Color? shadowColor, double shadowBlurRadius = 0, IconData? icon, Color? iconColor, double iconSize = 22, Position iconPosition = Position.leading, Position labelPosition = Position.center})
→ Widget
-