getSecureInternal method
--- SECURE STORAGE INTERNALS --- Reads a value from the encrypted store (Keychain/KeyStore).
Why @protected? This should only be called by the generated mixin. The public API for tokens should be the type-safe generated property.
Implementation
/// Reads a value from the encrypted store (Keychain/KeyStore).
///
/// **Why @protected?** This should only be called by the generated mixin.
/// The public API for tokens should be the type-safe generated property.
@protected
Future<String?> getSecureInternal(String key) =>
_secureStorage.read(key: key);