LanguageManager class abstract
Constructors
Properties
- fallback → SupportedLocale
-
Default fallback from enum (customizable if needed)
no setter
- fallbackLocale → Locale
-
Fallback Locale object
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
supported
→ List<
SupportedLocale> -
Projects may override only if they want to customize the list.
no setter
-
supportedLocales
→ List<
Locale> -
Converts enum list → Flutter locales
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
Locale? deviceLocale) → Locale - Default resolution logic — only implemented ONCE ✅
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited